@@ -26,8 +26,8 @@ Generic Access to Thruks Config
 
 ######################################
 
-our $VERSION = '3.23.20250830';
-our $GIT_HASH = "5b30b35e2"; # set by dailydist make target
+our $VERSION = '3.23.20250916';
+our $GIT_HASH = "2ca2fd829"; # set by dailydist make target
 
 our $config;
 our $project_root = home() || confess('could not determine project_root from inc.');
@@ -35,7 +35,7 @@ our $project_root = home() || confess('could not determine project_root from inc
 my $base_defaults = {
     'name'                                  => 'Thruk',
     'fileversion'                           => $VERSION,
-    'released'                              => 'August 30, 2025',
+    'released'                              => 'September 16, 2025',
     'compression_format'                    => 'gzip',
     'ENCODING'                              => 'utf-8',
     'image_path'                            => $project_root.'/root/thruk/images',
@@ -220,6 +220,7 @@ my $base_defaults = {
     'default_user_timezone'                 => 'Server Setting',
     'pnp_url_regex'                         => '/pnp[^/]*/',
     'grafana_url_regex'                     => 'histou\.js\?|/grafana/',
+    'cookie_max_length'                     => 2000, # maximum length of cookie data
     'audit_logs'                            => {
                 'login'                         => 1,
                 'logout'                        => 1,
